@@ -1,4 +1,4 @@
-Analysis <- function(Functions, condition, replications, fixed_objects, cl, MPI, seed,
+Analysis <- function(Functions, condition, replications, fixed_objects, cl, MPI, seed, save,
                      save_results, save_results_out_rootdir, save_results_dirname, max_errors, bootSE, boot_draws,
                      save_generate_data, save_generate_data_dirname,
                      save_seeds, save_seeds_dirname, load_seed, export_funs, packages,
@@ -13,7 +13,7 @@ Analysis <- function(Functions, condition, replications, fixed_objects, cl, MPI,
                    generate=Functions$generate,
                    analyse=Functions$analyse,
                    fixed_objects=fixed_objects,
-                   max_errors=max_errors, packages=packages,
+                   max_errors=max_errors, packages=packages, save=save,
                    save_results_out_rootdir=save_results_out_rootdir,
                    save_generate_data=save_generate_data,
                    save_generate_data_dirname=save_generate_data_dirname,
@@ -25,7 +25,7 @@ Analysis <- function(Functions, condition, replications, fixed_objects, cl, MPI,
                    generate=Functions$generate,
                    analyse=Functions$analyse,
                    fixed_objects=fixed_objects,
-                   max_errors=max_errors, packages=packages,
+                   max_errors=max_errors, packages=packages, save=save,
                    save_results_out_rootdir=save_results_out_rootdir,
                    save_generate_data=save_generate_data,
                    save_generate_data_dirname=save_generate_data_dirname,
@@ -39,7 +39,7 @@ Analysis <- function(Functions, condition, replications, fixed_objects, cl, MPI,
             results <- foreach(i=1L:replications, .export=export_funs) %dopar%
                 mainsim(i, condition=condition, generate=Functions$generate,
                      analyse=Functions$analyse, fixed_objects=fixed_objects, load_seed=load_seed,
-                     max_errors=max_errors, save_generate_data=save_generate_data,
+                     max_errors=max_errors, save_generate_data=save_generate_data, save=save,
                      save_generate_data_dirname=save_generate_data_dirname, packages=packages,
                      save_seeds=save_seeds, save_seeds_dirname=save_seeds_dirname,
                      save_results_out_rootdir=save_results_out_rootdir,
@@ -50,7 +50,7 @@ Analysis <- function(Functions, condition, replications, fixed_objects, cl, MPI,
                 pbapply::pblapply(1L:replications, mainsim,
                                     condition=condition, generate=Functions$generate,
                                     analyse=Functions$analyse, load_seed=load_seed,
-                                    fixed_objects=fixed_objects, packages=packages,
+                                    fixed_objects=fixed_objects, packages=packages, save=save,
                                     save_results_out_rootdir=save_results_out_rootdir,
                                     max_errors=max_errors, save_generate_data=save_generate_data,
                                     save_generate_data_dirname=save_generate_data_dirname,
@@ -61,7 +61,7 @@ Analysis <- function(Functions, condition, replications, fixed_objects, cl, MPI,
                 parallel::parLapply(cl, 1L:replications, mainsim,
                                     condition=condition, generate=Functions$generate,
                                     analyse=Functions$analyse, load_seed=load_seed,
-                                    fixed_objects=fixed_objects, packages=packages,
+                                    fixed_objects=fixed_objects, packages=packages, save=save,
                                     save_results_out_rootdir=save_results_out_rootdir,
                                     max_errors=max_errors, save_generate_data=save_generate_data,
                                     save_generate_data_dirname=save_generate_data_dirname,
