@@ -103,7 +103,7 @@ test_that('SimDesign', {
     Final <- runSimulation(Design, generate=mysim, analyse=mycompute, summarise=mycollect,
                                replications = 2, save=TRUE, verbose = FALSE, filename = 'newfile')
     expect_equal(tmp[[1]]$bias.random_number[1], Final$bias.random_number[1])
-    SimClean('newfile.rds')
+    SimClean('newfile.rds', 'SIMDESIGN_CRASHFILE_SEEDS.rds')
 
     #seeds
     Final <- runSimulation(Design, generate=mysim, analyse=mycompute, summarise=mycollect, seed = 1:8,
@@ -199,7 +199,16 @@ test_that('SimDesign', {
                                replications = 1, parallel=FALSE, save=FALSE, verbose = FALSE))
     expect_error(runSimulation(Design, generate=mysim, analyse=mycompute, summarise=mycollect,
                            replications = 1, parallel=TRUE, ncores=2L,
-                           save=FALSE, ncores = 2, verbose = FALSE))
+                           save=FALSE, verbose = FALSE))
+
+    expect_error(runSimulation(Design, generate=mysim, analyse=mycompute, summarise=mycollect,
+                               replications = 1, parallel=TRUE, ncores=2L,
+                               save=TRUE, verbose = FALSE))
+    seeds <- readRDS('SIMDESIGN_CRASHFILE_SEEDS.rds')
+    # runSimulation(Design, generate=mysim, analyse=mycompute, summarise=mycollect,
+    #               replications = 1, parallel=TRUE, ncores=2L, load_seed=seeds[1,],
+    #               save=TRUE, verbose = FALSE, edit='analyse')
+    SimClean('SIMDESIGN_CRASHFILE_SEEDS.rds')
 
     mycompute <- function(condition, dat, fixed_objects = NULL){
         ret <- does_not_exist(TRUE)
@@ -434,7 +443,7 @@ test_that('SimDesign', {
     expect_error(runSimulation(Design, replications = 10, save=TRUE, save_details = list(tmpfilename = 'thisfile.rds'),
                   generate=Generate, analyse=Analyse1, summarise=Summarise, verbose=FALSE))
     expect_true('thisfile.rds' %in% dir())
-    SimClean('thisfile.rds')
+    SimClean('thisfile.rds', 'SIMDESIGN_CRASHFILE_SEEDS.rds')
     results <- runSimulation(Design, replications = 10, save=TRUE, save_details = list(tmpfilename = 'thisfile'),
                                generate=Generate, analyse=Analyse2, summarise=Summarise, filename = 'thatfile', verbose=FALSE)
     expect_true('thatfile.rds' %in% dir())
